@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.24.4"
+version     = "2.25.2"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/export/home/wwalker/work/orca/branches/gnome-2-24/bld"
+prefix      = "/usr"
 
 # The package name (should be "orca").
 #
