@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4384 2008-12-06 21:33:48Z joanied $"
-__version__   = "$Revision: 4384 $"
-__date__      = "$Date: 2008-12-06 16:33:48 -0500 (Sat, 06 Dec 2008) $"
+__id__        = "$Id: settings.py 4336 2008-11-17 18:15:32Z wwalker $"
+__version__   = "$Revision: 4336 $"
+__date__      = "$Date: 2008-11-17 13:15:32 -0500 (Mon, 17 Nov 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1000,15 +1000,6 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
-# Translators: see the regular expression note above.  This is for a
-# version of Mozilla Firefox, which chooses to create strange names
-# for itself at the drop of a hat. [[[TODO - JD: Not marked for
-# translation due to string freeze. I'm not convinced it needs to
-# be translated either.]]]
-#
-#setScriptMapping(re.compile(_('Shiretoko')), "Mozilla")
-setScriptMapping(re.compile('Shiretoko'), "Mozilla")
-
 # This is a temporary fix for the schema/FF 3.0 not being accessible
 # issue. (See GNOME bugs #535827 and #555466.)
 #
