@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,8 +14,8 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Provides an abtract class for working with speech servers.
 
@@ -24,17 +24,22 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py,v 1.20 2006/10/13 23:39:04 wwalker Exp $"
-__version__   = "$Revision: 1.20 $"
-__date__      = "$Date: 2006/10/13 23:39:04 $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: speechserver.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import logging
+import keynames
+import settings
+import orca
 log = logging.getLogger("speech")
 
 import debug
 
+from orca_i18n import _           # for gettext support
+
 class VoiceFamily(dict):
     """Holds the family description for a voice."""
 
@@ -53,6 +58,8 @@ class VoiceFamily(dict):
 
     def __init__(self, props):
         """Create and initialize VoiceFamily."""
+        dict.__init__(self)
+
         self.update(VoiceFamily.settings)
         if props:
             self.update(props)
@@ -84,7 +91,8 @@ class SayAllContext:
         self.currentOffset = startOffset
         self.endOffset     = endOffset
 
-class SpeechServer:
+
+class SpeechServer(object):
 
     """Provides speech server abstraction."""
 
@@ -173,11 +181,48 @@ class SpeechServer:
         """
         pass
 
-    def speakUtterances(self, list, acss=None, interrupt=True):
+    def speakKeyEvent(self, event_string, eventType):
+        """Speaks a key event immediately.
+
+        Arguments:
+        - event_string: string representing the key event as defined by
+                        input_event.KeyboardEvent.
+        - eventType:    key event type as one of orca.KeyEventType constants.
+
+        """
+        if eventType == orca.KeyEventType.PRINTABLE and \
+               event_string.decode("UTF-8").isupper():
+            voice = settings.voices[settings.UPPERCASE_VOICE]
+        else:
+            voice = settings.voices[settings.DEFAULT_VOICE]
+
+        # Check to see if there are localized words to be spoken for
+        # this key event.
+        #
+        event_string = keynames.getKeyName(event_string)
+
+        if eventType == orca.KeyEventType.LOCKING_LOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
+            event_string += " " + _("on")
+        elif eventType == orca.KeyEventType.LOCKING_UNLOCKED:
+            # Translators: this represents the state of a locking modifier
+            # key (e.g., Caps Lock)
+            #
+            event_string += " " + _("off")
+
+        logLine = "SPEECH OUTPUT: '" + event_string +"'"
+        debug.println(debug.LEVEL_INFO, logLine)
+        log.info(logLine)
+
+        self.speak(event_string, acss=voice)
+
+    def speakUtterances(self, utteranceList, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
 
         Arguments:
-        - list:      list of strings to be spoken
+        - utteranceList: list of strings to be spoken
         - acss:      acss.ACSS instance; if None,
                      the default voice settings will be used.
                      Otherwise, the acss settings will be
@@ -204,8 +249,8 @@ class SpeechServer:
         pass
 
     def isSpeaking(self):
-	""""Returns True if the system is currently speaking."""
-	return False
+        """"Returns True if the system is currently speaking."""
+        return False
 
     def sayAll(self, utteranceIterator, progressCallback):
         """Iterates through the given utteranceIterator, speaking
@@ -222,9 +267,9 @@ class SpeechServer:
                              COMPLETED.
         """
         for [context, acss] in utteranceIterator:
-            debug.println(debug.LEVEL_INFO,
-                          "SPEECH OUTPUT: '" + context.utterance + "'")
-            log.info("'%s'" % context.utterance)
+            logLine = "SPEECH OUTPUT: '" + context.utterance + "'"
+            debug.println(debug.LEVEL_INFO, logLine)
+            log.info(logLine)
             self.speak(context.utterance, acss)
 
     def increaseSpeechRate(self, step=5):
